==> jbpm-flow-0.5.1-sources.jar: org/jbpm/ruleflow/core/factory/StartNodeFactory.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jbpm.ruleflow.core.factory;

import org.jbpm.process.core.event.EventTypeFilter;
import org.jbpm.ruleflow.core.RuleFlowNodeContainerFactory;
import org.jbpm.workflow.core.Node;
import org.jbpm.workflow.core.NodeContainer;
import org.jbpm.workflow.core.node.EventTrigger;
import org.jbpm.workflow.core.node.StartNode;

/**
 *
 */
public class StartNodeFactory extends NodeFactory {

    public StartNodeFactory(RuleFlowNodeContainerFactory nodeContainerFactory, NodeContainer nodeContainer, long id) {
        super(nodeContainerFactory, nodeContainer, id);
    }

    protected Node createNode() {
        return new StartNode();
    }
    
    protected StartNode getStartNode() {
        return (StartNode) getNode();
    }

    public StartNodeFactory name(String name) {
        getNode().setName(name);
        return this;
    }    
    
    public StartNodeFactory trigger(String triggerEventType, String mapping) {
        EventTrigger trigger = new EventTrigger();
        EventTypeFilter eventFilter = new EventTypeFilter();
        eventFilter.setType(triggerEventType);
        trigger.addEventFilter(eventFilter);
        
        if (mapping != null) {
            trigger.addInMapping(mapping, getStartNode().getOutMapping(mapping));
        }

        getStartNode().addTrigger(trigger);
        
        return this;
    }
}

==> jbpm-flow-0.8.1-sources.jar: org/jbpm/ruleflow/core/factory/StartNodeFactory.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jbpm.ruleflow.core.factory;

import org.jbpm.process.core.event.EventTypeFilter;
import org.jbpm.ruleflow.core.RuleFlowNodeContainerFactory;
import org.jbpm.workflow.core.Node;
import org.jbpm.workflow.core.NodeContainer;
import org.jbpm.workflow.core.node.EventTrigger;
import org.jbpm.workflow.core.node.StartNode;

/**
 *
 */
public class StartNodeFactory extends NodeFactory {

    public StartNodeFactory(RuleFlowNodeContainerFactory nodeContainerFactory, NodeContainer nodeContainer, long id) {
        super(nodeContainerFactory, nodeContainer, id);
    }

    protected Node createNode() {
        return new StartNode();
    }
    
    protected StartNode getStartNode() {
        return (StartNode) getNode();
    }

    public StartNodeFactory name(String name) {
        getNode().setName(name);
        return this;
    } 
    public StartNodeFactory interrupting(boolean interrupting) {
        getStartNode().setInterrupting(interrupting);
        return this;
    }
    
    public StartNodeFactory trigger(String triggerEventType, String mapping) {
        EventTrigger trigger = new EventTrigger();
        EventTypeFilter eventFilter = new EventTypeFilter();
        eventFilter.setType(triggerEventType);
        trigger.addEventFilter(eventFilter);
        
        if (mapping != null) {
            trigger.addInMapping(mapping, getStartNode().getOutMapping(mapping));
        }

        getStartNode().addTrigger(trigger);
        
        return this;
    }
}
